#!/usr/bin/env python

# MIT License
# Copyright (c) 2021 Aahnik Daw

import os
from enum import Enum
from mimetypes import guess_type


class Position(str, Enum):
    top_left = "top_left"
    top_right = "top_right"
    centre = "centre"
    bottom_left = "bottom_left"
    bottom_right = "bottom_right"


offset_map = {
    "top_left": "10:10",
    "top_right": "W-w-10:10",
    "centre": "(W-w)/2:(H-h)/2",
    "bottom_left": "10:H-h-10",
    "bottom_right": "W-w-10:H-h-10",
}


class File:
    def __init__(self, path: str) -> None:
        if not os.path.isfile(path):
            raise FileNotFoundError(f"File {path} does not exist.")
        self.path = path
        self.type = self.find_type()

    def find_type(self) -> str:
        _type = guess_type(self.path)[0]
        if not _type:
            raise Exception(f"File type cant be recognized")

        _type = _type.split("/")[0]
        if _type in ["image", "video"]:
            return _type
        else:
            raise ValueError(f"Type {_type} is not supported.")


class Watermark:
    def __init__(
        self,
        overlay: File,
        pos: Position = Position.centre,
        offset: str = "",
    ) -> None:
        self.overlay = overlay
        self.pos = pos
        if not offset:
            offset = offset_map.get(self.pos)
        self.offset = offset


def apply_watermark(
    file: File,
    wtm: Watermark,
    output_file: str = "",
    frame_rate: int = 15,
    preset: str = "ultrafast",
) -> str:

    if not output_file:
        output_file = f"watered_{file.path}"
    command = f'ffmpeg -i {file.path} \
        -i {wtm.overlay.path} \
        -an -dn -sn -r {frame_rate} \
        -preset {preset} \
        -tune zerolatency  -tune fastdecode \
        -filter_complex "overlay={wtm.offset}" \
        {output_file}'

    print(f"Running command {command}")
    os.system(command)
    return output_file



# -*- coding: utf-8 -*-
from setuptools import setup

modules = \
['watermark']
setup_kwargs = {
    'name': 'watermark.py',
    'version': '0.0.3.post1',
    'description': 'A convenient python wrapper around FFmpeg to apply watermarks to images, gifs, and videos.',
    'long_description': '# watermark.py\n\n![PyPI](https://img.shields.io/pypi/v/watermark.py)\n![PyPI - Python Version](https://img.shields.io/pypi/pyversions/watermark.py)\n\nA convenient python wrapper around FFmpeg to apply watermarks to images, gifs,\nand videos.\n\n## Installation\n\n```shell\npip install watermark.py\n```\n\nYou need to install  [`ffmpeg`](https://ffmpeg.org/) seperately.\n\n## Usage\n\n```python\nfrom watermark import File, Watermark, apply_watermark, Position\n\nvideo = File("vid.mp4")\nwatermark = Watermark(File("im.png"), pos=Position.bottom_right)\n\napply_watermark(video, watermark)\n```\n\n## Used by\n\n- [telewater](https://github.com/aahnik/telewater)\nA telegram bot that applies watermark on images, gifs, and videos.\n',
    'author': 'aahnik',
    'author_email': 'daw@aahnik.dev',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/aahnik/watermark.py',
    'py_modules': modules,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
